@@ -8,7 +8,7 @@ from configparser import ConfigParser, ParsingError
 import yaml
 
 from jinja2 import Environment, FileSystemLoader
-from click import prompt, MissingParameter, BadParameter, Abort
+from click import prompt, Choice, MissingParameter, BadParameter, Abort
 
 from .utils import get_usermail, get_username, parse_list_option
 
@@ -18,6 +18,9 @@ TEMPLATE_BASE_DIR = os.path.join(
 )
 
 
+LICENSES = ["LGPL21", "BSD", "MIT", "Apache2"]
+
+
 def read_config_file(config_file, *command_args):
     """Read a configuration file and return the content as a dict."""
     try:
@@ -83,9 +86,23 @@ def check_params(params, param_names, group):
             params[group][param_name] = param.replace(" ", "_")
 
 
-def _prompt_param(params, param, text, default=None, show_default=True):
+def _prompt_param(
+    params,
+    param,
+    text,
+    default=None,
+    show_default=True,
+    param_type=None,
+    show_choices=True,
+):
     if param not in params or not params[param]:
-        params[param] = prompt(text=text, default=default, show_default=show_default)
+        params[param] = prompt(
+            text=text,
+            default=default,
+            show_default=show_default,
+            type=param_type,
+            show_choices=show_choices,
+        )
 
 
 def prompt_params(params, params_dict, group):
@@ -110,19 +127,28 @@ def prompt_global_params(params):
     _params = params["global"]
     if "year" not in params or not _params["year"]:
         _params["year"] = datetime.datetime.now().year
+    if "license" not in params:
+        _prompt_param(
+            _params,
+            "license",
+            "License",
+            param_type=Choice(LICENSES),
+            show_choices=True,
+        )
     _prompt_param(_params, "author_name", "Author name", default=get_username())
     _prompt_param(_params, "author_email", "Author email", default=get_usermail())
     _prompt_param(_params, "organization", "Organization", default=get_username())
 
 
-def render_file(context, template_dir, source, dest):
+def render_file(context, group, source, dest):
     """Generate a file from an input template and a dict of parameters."""
-    loader = FileSystemLoader(searchpath=template_dir)
+    loader = FileSystemLoader(searchpath=TEMPLATE_BASE_DIR)
     env = Environment(
         loader=loader, trim_blocks=True, lstrip_blocks=True, keep_trailing_newline=True
     )
+    source_file = group + "/" + source
     env.globals.update(zip=zip)
-    template = env.get_template(source)
+    template = env.get_template(source_file)
     render = template.render(**context)
     with open(dest, "w") as f_dest:
         f_dest.write(render)
@@ -130,7 +156,6 @@ def render_file(context, template_dir, source, dest):
 
 def render_source(context, group, input_files, output_dir):
     """Generate a list of files given from an input template directory."""
-    template_dir = os.path.join(TEMPLATE_BASE_DIR, group)
     if not os.path.isdir(output_dir):
         os.makedirs(output_dir)
 
@@ -140,7 +165,7 @@ def render_source(context, group, input_files, output_dir):
         else:
             dest = dest.format(name=context[group]["name"])
         dest = os.path.join(output_dir, dest)
-        render_file(context, template_dir, source + ".j2", dest)
+        render_file(context, group, source + ".j2", dest)
 
 
 def generate(
@@ -171,12 +196,23 @@ def generate(
 
     if in_riot_dir is None:
         params[group]["riotbase"] = riotbase
+    else:
+        params["global"]["license"] = "LGPL21"
 
     if interactive:
         prompt_params(params, params_descriptor, group)
         prompt_params_list(params, group, *params_as_list)
         prompt_global_params(params)
 
+    licences_dir = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "data", "licenses"
+    )
+
+    with open(
+        os.path.join(licences_dir, params["global"]["license"] + ".txt")
+    ) as f_license:
+        params["global"]["license_header"] = f_license.read()
+
     check_params(params, params_descriptor.keys(), group)
     check_global_params(params)
 
